package heliumapi

import (
	"encoding/json"
	"fmt"
	"time"
)

type ActivityCounts struct {
	Data map[string]int
}

type RewardTotal struct {
	Meta struct {
		MinTime string `json:"min_time"`
		MaxTime string `json:"max_time"`
	} `json:"meta"`

	Data struct {
		Total  float64 `json:"total"`
		Sum    float64 `json:"sum"`
		Stddev float64 `json:"stddev"`
		Min    float64 `json:"min"`
		Median float64 `json:"median"`
		Max    float64 `json:"max"`
		Avg    float64 `json:"avg"`
	} `json:"data"`
}

func GetHotspotActivityCount(hotspot string) (*ActivityCounts, error) {
	path := "/v1/hotspots/" + hotspot + "/activity/count"

	// query the api
	respBody, err := getHeliumApi(path, nil)
	if err != nil {
		return nil, err
	}

	// unmarshal the response
	respobject := ActivityCounts{}
	err = json.Unmarshal(respBody, &respobject)
	if err != nil {
		return nil, fmt.Errorf("failed to unmarshal response from path %v: %v", path, err)
	}

	return &respobject, nil
}

func GetRewardsTotalForHotspot(hotspot string, minTime *time.Time, maxTime *time.Time) (*RewardTotal, error) {
	path := "/v1/hotspots/" + hotspot + "/rewards/sum"
	params := map[string]string{}
	if minTime != nil {
		params["min_time"] = minTime.UTC().Format("2006-01-02T15:04:05Z")
	}
	if maxTime != nil {
		params["max_time"] = maxTime.UTC().Format("2006-01-02T15:04:05Z")
	}

	// query the api
	respBody, err := getHeliumApi(path, &params)
	if err != nil {
		return nil, err
	}

	// unmarshal the response
	respobject := RewardTotal{}
	err = json.Unmarshal(respBody, &respobject)
	if err != nil {
		return nil, fmt.Errorf("failed to unmarshal response from path %v: %v", path, err)
	}

	return &respobject, nil
}
